Date: 08 10, 2001 11:28:59 AM

# Table of Spelling Functions

The NLP++ functions used to check spelling are listed here in table form for easy reference. For examples of these functions, refer to the individual function pages included in the Spelling Functions section.

Return types can be STR (string), INT (integer) or BOOL (Boolean). Boolean type is currently implemented by integer 1 (or non-zero) for true and 0 for false.

FUNCTION NAME | RETURNS | DESCRIPTION
spellcandidates(word_str) | STR | Make a list of space separated candidates for spell-correcting given word.
spellcorrect(word_str) | STR | Correct spelling of word. If word is not known, returns best spelling guess.
spellword(word_str) | BOOL | Check if word is a known English word.
strspellcandidate(word_str, list_str) | STR | Select best spell-correct candidate for a word, given a list of space-separated candidates (as returned by spellcandidates, e.g.)
strspellcompare(str1, str2) | INT | Measure spelling "distance" between two given words. The smaller the number, the fewer the corrections to get from one to the other.

## See Also

Special Functions

Knowledge Base Functions

Formatting and I/O Functions

Parse Tree Functions

String Functions